@@ -48,7 +48,7 @@ convert_array.geoarrow_vctr <- function(array, to, ...) {
 all_extension_names <- function() {
   c(
     "geoarrow.wkt", "geoarrow.wkb", "geoarrow.point", "geoarrow.linestring",
-    "geoarrow.polygon", "geoarrow.multipoint", "geoarrow.mutlilinestring",
+    "geoarrow.polygon", "geoarrow.multipoint", "geoarrow.multilinestring",
     "geoarrow.multipolygon", "geoarrow.box"
   )
 }
